km3modules\.common\.Cut
=======================

.. currentmodule:: km3modules.common

.. autoclass:: Cut

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Cut.__init__
      ~Cut.add
      ~Cut.configure
      ~Cut.expose
      ~Cut.finish
      ~Cut.get
      ~Cut.pre_finish
      ~Cut.process
      ~Cut.require
   
   

   
   
   